Vault
-----

.. autosimple:: swh.web.api.views.vault.api_vault_cook_directory

.. autosimple:: swh.web.api.views.vault.api_vault_fetch_directory

.. autosimple:: swh.web.api.views.vault.api_vault_cook_revision_gitfast

.. autosimple:: swh.web.api.views.vault.api_vault_fetch_revision_gitfast
